pub struct LatestArtifact { /* private fields */ }Expand description
One published artifact to copy to a stable convenience path.
Implementations
Sourceimpl LatestArtifact
impl LatestArtifact
Sourcepub fn same(id: ArtifactId) -> Self
pub fn same(id: ArtifactId) -> Self
Refresh a stable path with a published artifact of the same name.
Sourcepub fn new(source: ArtifactId, destination: ArtifactId) -> Self
pub fn new(source: ArtifactId, destination: ArtifactId) -> Self
Refresh a stable destination from a differently named published file.