pub struct LatestManifestArtifact {
pub source_relative_path: String,
pub destination_relative_path: String,
pub size: u64,
pub sha256: String,
}Expand description
Mapping from a published run artifact into one latest-generation alias.
Fields
source_relative_path: StringSource path relative to the published run.
destination_relative_path: StringStable public alias and path relative to the generation directory.
size: u64Exact file length in bytes.
sha256: StringLower-case hexadecimal SHA-256 digest.